Raw Numeric XBRL
================

All of the XBRL tagged numbers as reported in the XBRL documents submitted by the filers

.. automodule:: calcbench.raw_numeric_XBRL
    :members:
    :undoc-members: